*                                                                              .
*            SPSS Program to Score the TIMSS 2007 8th Grade Items              .
*                           TIMSS 2007 User Guide                              .
*                                                                              .

SET MPRINT=ON.

DEFINE SCOREIT (TYPE  = !CHAREND('/') /
                ITEM  = !CHAREND('/') /
                RIGHT = !CHAREND('/') /
                NR    = !CHAREND('/') /
                NA    = !CHAREND('/') /
                OM    = !CHAREND('/') /
                OTHER = !CHAREND('/') ) .

* Code for multiple-choice items .

 !IF (!UPCASE(!TYPE)=MC) !THEN
    !DO !I !IN (!ITEM) .
       RECODE !I (!RIGHT = 1      )
                 (!NR    = 0      ) /* Not Reached      */
                 (!NA    = SYSMIS ) /* Not Administered */
                 (!OM    = 0      ) /* Omitted          */
                 (!OTHER = 0      ) /* Other Missing    */
                 (ELSE   = 0      ) .
    !DOEND .
 !IFEND .

 * Code for constructed-response items .

 !IF (!UPCASE(!TYPE)=CR) !THEN
    !DO !I !IN (!ITEM).
       RECODE !I (10 THRU 19 = 1      )
                 (20 THRU 29 = 2      )
                 (30 THRU 39 = 3      )
                 (70 THRU 79 = 0      )
                 (!NR        = 0      ) /* Not Reached      */
                 (!NA        = SYSMIS ) /* Not Administered */
                 (!OM        = 0      ) /* Omitted          */
                 (!OTHER     = 0      ) /* Other Missing    */
                 (ELSE       = 0      ).
    !DOEND .
 !IFEND .

!ENDDEFINE.

DEFINE DOIT (COUNTRY = !CHAREND('/') ) .

* Specify the path for the SPSS data files following the format x:\xxx\ .
* <path> must be edited .

!LET !LIBDAT = !UNQUOTE("<path>") .

* Country loop .

!DO !CTY !IN (!COUNTRY) .

* Get the student achievement data .

ADD FILES
  / FILE = !QUOTE(!CONCAT(!LIBDAT,'bsa',!CTY,'m4.sav')) .

* Score multiple-choice items with A key .

SCOREIT  Type  = MC      /
         Item  = M042039  M042254  M022101  M032525  M042082  M042088  M042239
                 M042222  M042031  M032698  M032294  M042243  M042120  M032094
                 M032477  M032402  M042016  M032295  M032679  M042132  M042252
                 M042052  S032620  S022276  S022150  S042150  S022208  S022126
                 S042038  S042272  S032425  S032663  S042126  S032645  S042063
                 S032465  S042042  S032611  S032238  S032654  S042016  S042068
                 S042401  /
         RIGHT = 1       /
         NR    = 6       /
         NA    = sysmis  /
         OM    = 9       /
         OTHER = 7       .

* Score multiple-choice items with B key .

SCOREIT  Type  = MC      /
         Item  = M022062  M042055  M042148  M022181  M032523  M032704  M032579
                 M042001  M042279  M032142  M032205  M042032  M032273  M032575
                 M032529  M042060  M042255  M032116  M032397  M042024  M042067
                 M042150  M042260  M032331  M032047  M032398  M042158  M032166
                 M032721  M042202  M042268  S042001  S042279  S022183  S022294
                 S022042  S042013  S042109  S022181  S032385  S042141  S032672
                 S032257  S042257  S032542  S032151  S042073  S042007  S042024
                 S042311  S032579  S042003  S042222C S042218  S042217  S032158
                 S042249  S042164  /
         RIGHT = 2       /
         NR    = 6       /
         NA    = sysmis  /
         OM    = 9       /
         OTHER = 7       .

* Score multiple-choice items with C key .

SCOREIT  Type  = MC      /
         Item  = M022057  M022257  M042079  M042265  M042137  M022097  M022108
                 M032701  M042022  M042238  M032163  M042236  M042269  M042177
                 M032097  M042234  M042203  M032419  M042041  M042077  M032352
                 M032507  M032424  M042015  M042196  M042257  M042261  M032595
                 M032673  M042182  M042049  M042100  M042271  S032403  S032273
                 S042009  S042028  S042276  S042071  S042405  S022019  S022002
                 S022106  S042006  S042232C S042294  S032035  S032258  S042306
                 S042238A S032392  S042053  S042182  S042210  S032502  S032394
                 S042197  S032024  S032514  S042065  S042312  S032156  S032087
                 S032160  S042258  /
         RIGHT = 3       /
         NR    = 6       /
         NA    = sysmis  /
         OM    = 9       /
         OTHER = 7       .

* Score multiple-choice items with D key .

SCOREIT  Type  = MC      /
         Item  = M022043  M022049  M022066  M042003  M042199  M042273  M022104
                 M022105  M042267  M042036  M032198  M042245  M042152  M042179
                 M032416  M032160  M032540  M042183  M032662  M032324  M032100
                 M032132  M042235  M032738  M032623  M042112  M042109  M032626
                 M042076  M042240  S032115  S042059  S022115  S042054  S042061
                 S022290  S022054  S032683  S042304  S042215  S032606  S032660
                 S042015  S042309  S032184  S042017  S042095  S042112  S042274
                 S032315  S032141  S032463  S042110  S042280  S032279  S032510
                 S042216  /
         RIGHT = 4       /
         NR    = 6       /
         NA    = sysmis  /
         OM    = 9       /
         OTHER = 7       .

* Score multiple-choice items with E key .

SCOREIT  Type  = MC      /
         Item  = M022050 /
         RIGHT = 5       /
         NR    = 6       /
         NA    = sysmis  /
         OM    = 9       /
         OTHER = 7       .

* Score Constructed-Response Items .

SCOREIT  Type  = CR      /
         Item  = M022046  M022055  M022232  M022234A M022234B M022243  M042018
                 M042301A M042301B M042301C M042263  M042250  M042220  M022106
                 M022110  M032307  M032691  M042304A M042304B M042304C M042304D
                 M042130  M042303A M042303B M032640  M032344  M032754  M032755
                 M032753A M032753B M032753C M032756  M042186  M042059  M042226
                 M042103  M042086  M042228  M042270  M042201  M042207  M032381
                 M032414  M032688  M032637A M032637B M032637C M042019  M042023
                 M042197  M042066  M042248  M042229A M042229B M042080A M042080B
                 M042264  M042224  M032064  M032538  M032734  M032695  M042002
                 M042198A M042198B M042198C M042300A M042300B M042169A M042169B
                 M042169C M032725  M032683  M032681A M032681B M032681C M042194
                 M042114A M042114B M042050  M042074A M042074B M042074C M042151
                 M032757  M032760A M032760B M032760C M032761  M032692  M042081
                 M042302A M042302B M042302C M042093  M042159  M042164  M042167
                 S032565  S032019A S032019B S032516  S032693A S032693B S032695
                 S032697A S032697B S032697D S042313  S042011  S042083  S042106
                 S042101  S042307  S042244A S042244B S042153  S022022  S022244
                 S022289  S022069  S022268  S042310  S042052  S042043  S042196
                 S042292  S042232A S042232B S042149  S042155  S022292  S022078
                 S022281  S032519  S032120A S032120B S042298  S042261  S042051A
                 S042051B S042076  S042404  S042403  S042100  S042238B S042238C
                 S032015  S032310A S032310B S032310D S032680  S032555  S032122
                 S042408  S042049A S042049B S042402  S042228A S042228B S042228C
                 S042176  S042211  S042135  S032530A S032530B S032530D S032007
                 S032679  S032651A S032651B S032665A S032665B S032665C S042022
                 S042297  S042305  S042173  S042173A S042173B S042173C S042173D
                 S042173E S042407  S042278  S042317  S032306  S032640  S032570
                 S032272  S032060  S032650A S032650B S032650D S042030  S042222A
                 S042222B S042088  S042104  S042064  S042273  S042301  S042406
                 S032614  S032451  S032056  S032369  S032126  S042005  S042300A
                 S042300B S042300C S042319  S042094  S042293A S042293B S042195
                 S042400  /
         RIGHT =  0      /  
         NR    = 96      /  
         NA    = sysmis  /  
         OM    = 99      /  
         OTHER = 90      .

EXECUTE.

* Save the student data .

SAVE OUTFILE = !QUOTE(!CONCAT(!LIBDAT,'bsc',!CTY,'m4.sav')) .

!DOEND .

!ENDDEFINE .

* Specify the list of countries to be processed .

DOIT COUNTRY = dza arm aus bhr bih bwa bgr twn col cyp
               cze egy slv eng geo gha hkg hun idn irn
               isr ita jpn jor kor kwt lbn ltu mys mlt
               mng mar nor omn pse qat rom rus sau sco
               scg sgp svn swe syr tha tun tur ukr usa
               adu bsq cbc cot cqu uma umn .
